Overview
========

Opendnp3 is a portable, scalable, and rigorously tested implementation 
of the DNP3 (www.dnp.org) protocol stack written in C++11. The library 
is designed for high-performance applications like many concurrent TCP
sessions or huge device simulations. It also embeds with a small footprint on Linux.

Documentation
=============

The documentation can be found on the [project homepage](http://www.automatak.com/opendnp3/#documentation).

If you want to help contribute to the official guide its in [this repo](https://github.com/automatak/dnp3-guide).

License
=============

Licensed under the terms of the [Apache 2.0 License](http://www.apache.org/licenses/LICENSE-2.0.html).

Copyright (c) 2010, 2011 Green Energy Corp

Copyright (c) 2013 - 2015 Automatak LLC

Copyright (c) 2010 - 2015 various contributors




    

